@@ -1,14 +1,26 @@
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2013-2014
-# License: GNU GPL v2 or higher
+# Copyright: 2013-2015 Dmitry Shachnev
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
 from ReText import globalSettings
 from markups.common import CONFIGURATION_DIR
 from os.path import join
 
-from PyQt5.QtCore import QFileInfo, Qt
-from PyQt5.QtGui import QIcon
+from PyQt5.QtCore import QFileInfo, QUrl, Qt
+from PyQt5.QtGui import QDesktopServices, QIcon
 from PyQt5.QtWidgets import QCheckBox, QDialog, QDialogButtonBox, \
  QFileDialog, QGridLayout, QLabel, QLineEdit, QPushButton, QSpinBox
 
@@ -57,8 +69,10 @@ class ConfigDialog(QDialog):
 			(self.tr('Restore window geometry'), 'saveWindowGeometry'),
 			(self.tr('Restore live preview state'), 'restorePreviewState'),
 			(self.tr('Open external links in ReText window'), 'handleWebLinks'),
-			(self.tr('Open unknown files in plain text mode'), 'autoPlainText'),
-			(self.tr('Markdown extensions (comma-separated)'), 'markdownExtensions'), (None, 'markdownExtensions'),
+			(self.tr('Markdown syntax extensions (comma-separated)'), 'markdownExtensions'),
+			(None, 'markdownExtensions'),
+		#	(self.tr('Default Markdown file extension'), 'markdownDefaultFileExtension'),
+		#	(self.tr('Default reStructuredText file extension'), 'restDefaultFileExtension'),
 			(self.tr('Editor'), None),
 			(self.tr('Highlight current line'), 'highlightCurrentLine'),
 			(self.tr('Show line numbers'), 'lineNumbersEnabled'),
@@ -69,7 +83,6 @@ class ConfigDialog(QDialog):
 			(self.tr('Icon theme name'), 'iconTheme'),
 			(self.tr('Color scheme file'), 'colorSchemeFile', True),
 			(self.tr('Stylesheet file'), 'styleSheet', True),
-			# Ideas for future: styleSheet, editorFont
 		)
 
 	def initWidgets(self):
@@ -85,7 +98,11 @@ class ConfigDialog(QDialog):
 				label = QLabel(displayname + ':', self)
 			if name == 'markdownExtensions':
 				if displayname:
-					self.layout.addWidget(label, index, 0, 1, 2)
+					url = QUrl('http://pythonhosted.org/Markdown/extensions/')
+					helpButton = QPushButton(self.tr('Help'), self)
+					helpButton.clicked.connect(lambda: QDesktopServices.openUrl(url))
+					self.layout.addWidget(label, index, 0)
+					self.layout.addWidget(helpButton, index, 1)
 					continue
 				try:
 					extsFile = open(MKD_EXTS_FILE)
@@ -146,3 +163,4 @@ class ConfigDialog(QDialog):
 			print(e, file=sys.stderr)
 		for editBox in self.parent.editBoxes:
 			editBox.updateLineNumberAreaWidth()
+		self.parent.updateStyleSheet()
