@@ -1,8 +1,20 @@
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012-2014
-# License: GNU GPL v2 or higher
+# Copyright: 2012-2015 Dmitry Shachnev
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from ReText import monofont, DOCTYPE_HTML
+from ReText import globalSettings, DOCTYPE_HTML
 from ReText.highlighter import ReTextHighlighter
 
 from PyQt5.QtWidgets import QCheckBox, QDialog, QDialogButtonBox, \
@@ -15,7 +27,7 @@ class HtmlDialog(QDialog):
 		verticalLayout = QVBoxLayout(self)
 		self.textEdit = QTextEdit(self)
 		self.textEdit.setReadOnly(True)
-		self.textEdit.setFont(monofont)
+		self.textEdit.setFont(globalSettings.editorFont)
 		self.hl = ReTextHighlighter(self.textEdit.document())
 		self.hl.docType = DOCTYPE_HTML
 		verticalLayout.addWidget(self.textEdit)
