@@ -3,100 +3,100 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Behavior</source>
         <translation>Comportement</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Automatically save documents</source>
         <translation>Sauvegarde automatique des documents</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore window geometry</source>
         <translation>Restaurer la taille de la fenêtre</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore live preview state</source>
         <translation>Restaurer l&apos;état de l&apos;aperçu direct</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Open external links in ReText window</source>
         <translation>Ouvrir les liens externes dans la fenêtre de ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Open unknown files in plain text mode</source>
-        <translation>Ouvrir les fichiers de type inconnu en mode texte</translation>
+        <location filename="config.py" line="66"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Extensions liées à la syntaxe Markdown (séparées par une virgule)</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Markdown extensions (comma-separated)</source>
-        <translation>Extensions Markdown (séparées par une virgule)</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Editor</source>
-        <translation>Editeur</translation>
+        <translation>Éditeur</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Highlight current line</source>
         <translation>Surligner la ligne courante</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Show line numbers</source>
         <translation>Afficher les numéros de ligne</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tab key inserts spaces</source>
-        <translation>La touche Tab insert des espaces</translation>
+        <translation>La touche Tab insère des espaces</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tabulation width</source>
         <translation>Largeur de tabulation</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Display right margin at column</source>
         <translation>Afficher la marge de droite à la colonne</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Interface</source>
         <translation>Interface</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Icon theme name</source>
         <translation>Nom du thème d’icônes</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Color scheme file</source>
         <translation>Fichier de thème de couleur</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Stylesheet file</source>
         <translation>Fichier de feuille de style</translation>
     </message>
+    <message>
+        <location filename="config.py" line="102"/>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="21"/>
+        <location filename="config.py" line="33"/>
         <source>(none)</source>
         <translation>(aucun)</translation>
     </message>
     <message>
-        <location filename="config.py" line="28"/>
+        <location filename="config.py" line="40"/>
         <source>Select file to open</source>
         <translation>Choisir le fichier à ouvrir</translation>
     </message>
@@ -104,436 +104,454 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="32"/>
+        <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Entrez le préfixe pour la langue (exemple: fr_FR)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="37"/>
+        <location filename="dialogs.py" line="49"/>
         <source>Set as default</source>
         <translation>Définir par défaut</translation>
     </message>
 </context>
+<context>
+    <name>Proxy</name>
+    <message>
+        <location filename="fakevimeditor.py" line="64"/>
+        <source>No write since last change (add ! to override)</source>
+        <translation>Aucune modification depuis la dernière sauvegarde (ajoutez ! pour écraser)</translation>
+    </message>
+    <message>
+        <location filename="fakevimeditor.py" line="121"/>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+</context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="61"/>
+        <location filename="window.py" line="82"/>
         <source>File toolbar</source>
         <translation>Barre d&apos;outil Fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="63"/>
+        <location filename="window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>Barre d&apos;outil Édition</translation>
     </message>
     <message>
-        <location filename="window.py" line="65"/>
+        <location filename="window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>Barre d&apos;outil de recherche</translation>
     </message>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="90"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="window.py" line="72"/>
+        <location filename="window.py" line="93"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
+        <location filename="window.py" line="96"/>
         <source>Set encoding</source>
         <translation>Définir l&apos;encodage</translation>
     </message>
     <message>
-        <location filename="window.py" line="78"/>
+        <location filename="window.py" line="1217"/>
         <source>Reload</source>
         <translation>Recherger</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="window.py" line="84"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Enregistrer Sous</translation>
     </message>
     <message>
-        <location filename="window.py" line="86"/>
+        <location filename="window.py" line="107"/>
         <source>Next tab</source>
         <translation>Onglet suivant</translation>
     </message>
     <message>
-        <location filename="window.py" line="88"/>
+        <location filename="window.py" line="109"/>
         <source>Previous tab</source>
         <translation>Onglet précédent</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>Aperçu avant impression</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>Voir le code HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
-        <source>Change default font</source>
-        <translation>Changer la police par défaut</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Rechercher un texte</translation>
     </message>
     <message>
-        <location filename="window.py" line="101"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="window.py" line="110"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Aperçu direct</translation>
     </message>
     <message>
-        <location filename="window.py" line="112"/>
+        <location filename="window.py" line="137"/>
         <source>Table mode</source>
         <translation>Mode table</translation>
     </message>
     <message>
-        <location filename="window.py" line="114"/>
+        <location filename="window.py" line="140"/>
+        <source>FakeVim mode</source>
+        <translation>Imitation de Vim</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="145"/>
         <source>Fullscreen mode</source>
         <translation>Mode plein écran</translation>
     </message>
     <message>
-        <location filename="window.py" line="564"/>
+        <location filename="window.py" line="592"/>
         <source>Preferences</source>
         <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="window.py" line="122"/>
+        <location filename="window.py" line="155"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="window.py" line="158"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="window.py" line="127"/>
+        <location filename="window.py" line="160"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="window.py" line="162"/>
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="164"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location filename="window.py" line="133"/>
+        <location filename="window.py" line="166"/>
         <source>Paste</source>
         <translation>Coller</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="176"/>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="window.py" line="177"/>
         <source>Set locale</source>
         <translation>Choisir la langue</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
-        <source>Plain text</source>
-        <translation>Texte brut</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="178"/>
         <source>Use WebKit renderer</source>
         <translation>Utiliser le rendu de WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
-        <source>Generate webpages</source>
-        <translation>Générer les pages web</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="149"/>
-        <source>Show</source>
-        <translation>Afficher</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="150"/>
-        <source>Next</source>
-        <translation>Suivant</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="152"/>
-        <source>Previous</source>
-        <translation>Précédent</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="154"/>
-        <source>Get help online</source>
-        <translation>Assistance en ligne</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>About %s</source>
-        <comment>Example of final string: About ReText</comment>
-        <translation>À propos de %s</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="159"/>
-        <source>About Qt</source>
-        <translation>À propos de Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="179"/>
-        <source>Bold</source>
-        <translation>Gras</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Italic</source>
-        <translation>Italique</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Underline</source>
-        <translation>Souligné</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Tags</source>
-        <translation>Mots-clefs</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="195"/>
-        <source>Symbols</source>
-        <translation>Symboles</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>File</source>
-        <translation>Fichier</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="210"/>
-        <source>Edit</source>
-        <translation>Édition</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Help</source>
-        <translation>Aide</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="214"/>
-        <source>Open recent</source>
-        <translation>Ouvrir les fichiers récents</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="217"/>
-        <source>Directory</source>
-        <translation>Répertoire</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="229"/>
-        <source>Export</source>
-        <translation>Exporter</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Spell check</source>
-        <translation>Vérifier l&apos;orthographe</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="258"/>
-        <source>Default markup</source>
-        <translation>Balisage par défaut</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="261"/>
-        <source>Formatting</source>
-        <translation>Formatage</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Search</source>
-        <translation>Rechercher</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="301"/>
-        <source>Case sensitively</source>
-        <translation>Sensible à la casse</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1121"/>
-        <source>New document</source>
-        <translation>Nouveau document</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="641"/>
-        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>Impossible d&apos;analyser le contenu du fichier, vérifier si les &lt;a href=&quot;%s&quot;&gt;modules nécessaires&lt;/a&gt; sont installés!</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="739"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Veuillez enregistrer le fichier quelque part.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="724"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
-        <translation>Impossible de copier le modèle par défaut, merci de créer le fichier template.html manuellement.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="728"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>Pages web enregistrées dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="730"/>
+        <location filename="window.py" line="180"/>
         <source>Show directory</source>
         <translation>Afficher le répertoire</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
+        <location filename="window.py" line="181"/>
+        <source>Next</source>
+        <translation>Suivant</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="183"/>
+        <source>Previous</source>
+        <translation>Précédent</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="185"/>
+        <source>Get help online</source>
+        <translation>Assistance en ligne</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="186"/>
+        <source>About ReText</source>
+        <translation>À propos de ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="189"/>
+        <source>About Qt</source>
+        <translation>À propos de Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="209"/>
+        <source>Bold</source>
+        <translation>Gras</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="211"/>
+        <source>Italic</source>
+        <translation>Italique</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="213"/>
+        <source>Underline</source>
+        <translation>Souligné</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="221"/>
+        <source>Tags</source>
+        <translation>Mots-clefs</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Symbols</source>
+        <translation>Symboles</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="232"/>
+        <source>File</source>
+        <translation>Fichier</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="233"/>
+        <source>Edit</source>
+        <translation>Édition</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="234"/>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Open recent</source>
+        <translation>Ouvrir les fichiers récents</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="250"/>
+        <source>Export</source>
+        <translation>Exporter</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="271"/>
+        <source>Spell check</source>
+        <translation>Vérifier l&apos;orthographe</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="279"/>
+        <source>Default markup</source>
+        <translation>Balisage par défaut</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="282"/>
+        <source>Formatting</source>
+        <translation>Formatage</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="323"/>
+        <source>Search</source>
+        <translation>Rechercher</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="325"/>
+        <source>Case sensitively</source>
+        <translation>Sensible à la casse</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1141"/>
+        <source>New document</source>
+        <translation>Nouveau document</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="685"/>
+        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <translation>Impossible d&apos;analyser le contenu du fichier, vérifier si les &lt;a href=&quot;%s&quot;&gt;modules nécessaires&lt;/a&gt; sont installés!</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="748"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Veuillez enregistrer le fichier quelque part.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
         <source>Select one or several files to open</source>
         <translation>Choisir un ou plusieurs fichiers à ouvrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
+        <location filename="window.py" line="868"/>
         <source>Supported files</source>
         <translation>Formats acceptés</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
+        <location filename="window.py" line="868"/>
         <source>All files (*)</source>
         <translation>Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="917"/>
+        <location filename="window.py" line="927"/>
         <source>Select file encoding from the list:</source>
         <translation>Choisir l&apos;encodage du fichier dans la liste</translation>
     </message>
     <message>
-        <location filename="window.py" line="942"/>
+        <location filename="window.py" line="952"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichiers texte (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="945"/>
+        <location filename="window.py" line="955"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Fichers %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
+        <location filename="window.py" line="1040"/>
         <source>Save file</source>
         <translation>Enregistrer le fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="965"/>
+        <location filename="window.py" line="982"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Impossible d&apos;enregistrer le fichier car il est en lecture seule !</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
+        <location filename="window.py" line="1030"/>
         <source>Export document to ODT</source>
         <translation>Exporter le document au format ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
+        <location filename="window.py" line="1030"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichiers OpenDocument texte (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
+        <location filename="window.py" line="1040"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichiers HTML (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
+        <location filename="window.py" line="1062"/>
         <source>Export document to PDF</source>
         <translation>Exporter le document au format PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
+        <location filename="window.py" line="1062"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="1079"/>
         <source>Print document</source>
         <translation>Imprimer le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="window.py" line="1100"/>
         <source>Export document</source>
         <translation>Exporter le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1099"/>
+        <location filename="window.py" line="1119"/>
         <source>Failed to execute the command:</source>
         <translation>Échec lors de l&apos;exécution de la commande :</translation>
     </message>
     <message>
-        <location filename="window.py" line="1180"/>
+        <location filename="window.py" line="1200"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation>Ce fichier a été supprimé par une autre application.
+Pensez à vérifier que vous sauvegardez le fichier avant de quitter.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1208"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation>Ce document a été modifié par une autre application.
+Voulez-vous recharger le fichier (vos modifications seront perdues) ?
+</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1213"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation>Si vous choisissez de ne pas recharger le fichier, la sauvegarde automatique sera désactivée pour cette session afin d&apos;éviter une perte de données.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1237"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a été modifié.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1204"/>
+        <location filename="window.py" line="1261"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Éditeur de Markdown et ReStructuredText simple mais puissant</translation>
+        <translation>Éditeur de Markdown et reStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>reStructuredText syntax</source>
         <translation>Syntaxe reStructuredText</translation>
     </message>
+    <message>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
