@@ -3,537 +3,555 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>動作設定</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Automatically save documents</source>
-        <translation type="unfinished"></translation>
+        <translation>文書を自動保存する</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore window geometry</source>
-        <translation type="unfinished"></translation>
+        <translation>ウィンドウの表示位置を記憶する</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore live preview state</source>
-        <translation type="unfinished"></translation>
+        <translation>ライブプレビューの状態を記憶する</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Open external links in ReText window</source>
-        <translation type="unfinished"></translation>
+        <translation>外部リンクを ReText ウィンドウ内で開く</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Open unknown files in plain text mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="config.py" line="66"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Markdown記法の拡張(カンマ区切り)</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Editor</source>
-        <translation type="unfinished"></translation>
+        <translation>エディタ</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Highlight current line</source>
-        <translation type="unfinished"></translation>
+        <translation>カーソル行をハイライト表示する</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Show line numbers</source>
-        <translation type="unfinished"></translation>
+        <translation>行番号を表示する</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tab key inserts spaces</source>
-        <translation type="unfinished"></translation>
+        <translation>タブをスペースに展開</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tabulation width</source>
-        <translation type="unfinished"></translation>
+        <translation>タブの桁数</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Display right margin at column</source>
-        <translation type="unfinished"></translation>
+        <translation>右マージン表示桁</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Interface</source>
-        <translation type="unfinished"></translation>
+        <translation>外観</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Icon theme name</source>
-        <translation type="unfinished"></translation>
+        <translation>アイコンテーマ名</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Markdown extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Color scheme file</source>
-        <translation type="unfinished"></translation>
+        <translation>カラースキーマファイル</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
+        <translation>スタイルシートファイル</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="102"/>
+        <source>Help</source>
+        <translation>ヘルプ</translation>
     </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="21"/>
+        <location filename="config.py" line="33"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>（未設定）</translation>
     </message>
     <message>
-        <location filename="config.py" line="28"/>
+        <location filename="config.py" line="40"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>ファイルを開く</translation>
     </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="32"/>
+        <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
+        <translation>ロケール名を入力してください (例：ja_JP)</translation>
+    </message>
+    <message>
+        <location filename="dialogs.py" line="49"/>
+        <source>Set as default</source>
+        <translation>デフォルトにする</translation>
+    </message>
+</context>
+<context>
+    <name>Proxy</name>
+    <message>
+        <location filename="fakevimeditor.py" line="64"/>
+        <source>No write since last change (add ! to override)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="37"/>
-        <source>Set as default</source>
+        <location filename="fakevimeditor.py" line="121"/>
+        <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="61"/>
+        <location filename="window.py" line="82"/>
         <source>File toolbar</source>
         <translation>ファイルツールバー</translation>
     </message>
     <message>
-        <location filename="window.py" line="63"/>
+        <location filename="window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>編集ツールバー</translation>
     </message>
     <message>
-        <location filename="window.py" line="65"/>
+        <location filename="window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>検索ツールバー</translation>
     </message>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="90"/>
         <source>New</source>
         <translation>新規</translation>
     </message>
     <message>
-        <location filename="window.py" line="72"/>
+        <location filename="window.py" line="93"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="96"/>
+        <source>Set encoding</source>
+        <translation>文字エンコーディング</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1217"/>
+        <source>Reload</source>
+        <translation>再読み込み</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="84"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="107"/>
+        <source>Next tab</source>
+        <translation>次のタブへ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Previous tab</source>
+        <translation>前のタブへ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>印刷</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>印刷プレビュー</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>HTMLコードを表示</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
-        <source>Change default font</source>
-        <translation>規定のフォントを変更</translation>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation>エディターのフォントを変更</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation>プレビューのフォントを変更</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>テキストを検索</translation>
     </message>
     <message>
-        <location filename="window.py" line="101"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>プレビュー</translation>
     </message>
     <message>
-        <location filename="window.py" line="110"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>ライブプレビュー</translation>
     </message>
     <message>
-        <location filename="window.py" line="114"/>
+        <location filename="window.py" line="137"/>
+        <source>Table mode</source>
+        <translation>表組みモード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="140"/>
+        <source>FakeVim mode</source>
+        <translation>擬似Vimモード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="145"/>
         <source>Fullscreen mode</source>
         <translation>フルスクリーンモード</translation>
     </message>
     <message>
-        <location filename="window.py" line="122"/>
+        <location filename="window.py" line="592"/>
+        <source>Preferences</source>
+        <translation>設定</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
         <source>Quit</source>
         <translation>終了</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="window.py" line="158"/>
         <source>Undo</source>
         <translation>元に戻す</translation>
     </message>
     <message>
-        <location filename="window.py" line="127"/>
+        <location filename="window.py" line="160"/>
         <source>Redo</source>
         <translation>やり直す</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="window.py" line="162"/>
         <source>Copy</source>
         <translation>コピー</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="164"/>
         <source>Cut</source>
         <translation>切り取り</translation>
     </message>
     <message>
-        <location filename="window.py" line="133"/>
+        <location filename="window.py" line="166"/>
         <source>Paste</source>
         <translation>貼り付け</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="176"/>
         <source>Enable</source>
         <translation>有効</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="window.py" line="177"/>
         <source>Set locale</source>
         <translation>ロケールの設定</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
-        <source>Plain text</source>
-        <translation>プレーンテキスト</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="178"/>
         <source>Use WebKit renderer</source>
         <translation>WebKitレンダラーを使用</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
-        <source>Generate webpages</source>
-        <translation>Webページを生成</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="149"/>
-        <source>Show</source>
-        <translation>表示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="150"/>
-        <source>Next</source>
-        <translation>次へ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="152"/>
-        <source>Previous</source>
-        <translation>前へ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="154"/>
-        <source>Get help online</source>
-        <translation>オンラインでヘルプを読む</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>About %s</source>
-        <comment>Example of final string: About ReText</comment>
-        <translation>%s について</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="159"/>
-        <source>About Qt</source>
-        <translation>Qtについて</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="179"/>
-        <source>Bold</source>
-        <translation>太字</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Italic</source>
-        <translation>斜体</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Underline</source>
-        <translation>下線</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Tags</source>
-        <translation>タグ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="195"/>
-        <source>Symbols</source>
-        <translation>シンボル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>File</source>
-        <translation>ファイル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="210"/>
-        <source>Edit</source>
-        <translation>編集</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Help</source>
-        <translation>ヘルプ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="214"/>
-        <source>Open recent</source>
-        <translation>最近使用したファイル</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="217"/>
-        <source>Directory</source>
-        <translation>ディレクトリ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="229"/>
-        <source>Export</source>
-        <translation>エクスポート</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Spell check</source>
-        <translation>スペルチェック</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="261"/>
-        <source>Formatting</source>
-        <translation>書式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Search</source>
-        <translation>検索</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="301"/>
-        <source>Case sensitively</source>
-        <translation>大文字と小文字を区別</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1121"/>
-        <source>New document</source>
-        <translation>新規文書</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="641"/>
-        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>ファイルの内容を解析できません。&lt;a href=&quot;%s&quot;&gt;必要なモジュール&lt;/a&gt; がインストールされているか確認してください。</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="739"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>どこかにファイルを保存してください.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="724"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
-        <translation>デフォルトのテンプレートをコピーできませんでした。template.html を手動で作成してください。</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="728"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>Webページを&lt;code&gt;html&lt;/code&gt;ディレクトリに保存しました.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="730"/>
+        <location filename="window.py" line="180"/>
         <source>Show directory</source>
         <translation>ディレクトリを表示</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
-        <source>Select one or several files to open</source>
-        <translation>開くには一つまたは複数のファイルを選択します</translation>
+        <location filename="window.py" line="181"/>
+        <source>Next</source>
+        <translation>次へ</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
-        <source>Supported files</source>
-        <translation>サポートされているファイル</translation>
+        <location filename="window.py" line="183"/>
+        <source>Previous</source>
+        <translation>前へ</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
-        <source>All files (*)</source>
-        <translation>すべてのファイル (*)</translation>
+        <location filename="window.py" line="185"/>
+        <source>Get help online</source>
+        <translation>オンラインでヘルプを読む</translation>
     </message>
     <message>
-        <location filename="window.py" line="942"/>
-        <source>Plain text (*.txt)</source>
-        <translation>プレーンテキスト (*.txt)</translation>
+        <location filename="window.py" line="186"/>
+        <source>About ReText</source>
+        <translation>ReTextについて</translation>
     </message>
     <message>
-        <location filename="window.py" line="945"/>
-        <source>%s files</source>
-        <comment>Example of final string: Markdown files</comment>
-        <translation>%s 個のファイル</translation>
+        <location filename="window.py" line="189"/>
+        <source>About Qt</source>
+        <translation>Qtについて</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
-        <source>Save file</source>
-        <translation>ファイルを保存</translation>
+        <location filename="window.py" line="209"/>
+        <source>Bold</source>
+        <translation>太字</translation>
     </message>
     <message>
-        <location filename="window.py" line="965"/>
-        <source>Cannot save to file because it is read-only!</source>
-        <translation>読み取り専用ファイルなので保存できません!</translation>
+        <location filename="window.py" line="211"/>
+        <source>Italic</source>
+        <translation>斜体</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
-        <source>Export document to ODT</source>
-        <translation>文書をODTにエクスポート</translation>
+        <location filename="window.py" line="213"/>
+        <source>Underline</source>
+        <translation>下線</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
-        <source>OpenDocument text files (*.odt)</source>
-        <translation>OpenDocumentテキストファイル (*.odt)</translation>
+        <location filename="window.py" line="221"/>
+        <source>Tags</source>
+        <translation>タグ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
-        <source>HTML files (*.html *.htm)</source>
-        <translation>HTMLファイル (*.html *.htm)</translation>
+        <location filename="window.py" line="225"/>
+        <source>Symbols</source>
+        <translation>シンボル</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
-        <source>Export document to PDF</source>
-        <translation>文書をPDFにエクスポート</translation>
+        <location filename="window.py" line="232"/>
+        <source>File</source>
+        <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
-        <source>PDF files (*.pdf)</source>
-        <translation>PDFファイル (*.pdf)</translation>
+        <location filename="window.py" line="233"/>
+        <source>Edit</source>
+        <translation>編集</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
-        <source>Print document</source>
-        <translation>文書を印刷</translation>
+        <location filename="window.py" line="234"/>
+        <source>Help</source>
+        <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
-        <source>Export document</source>
-        <translation>文書をエクスポート</translation>
+        <location filename="window.py" line="237"/>
+        <source>Open recent</source>
+        <translation>最近使用したファイル</translation>
     </message>
     <message>
-        <location filename="window.py" line="1099"/>
-        <source>Failed to execute the command:</source>
-        <translation>コマンドの実行に失敗しました:</translation>
+        <location filename="window.py" line="250"/>
+        <source>Export</source>
+        <translation>エクスポート</translation>
     </message>
     <message>
-        <location filename="window.py" line="1180"/>
-        <source>The document has been modified.
-Do you want to save your changes?</source>
-        <translation>文書は変更されています.
-変更内容を保存しますか?</translation>
+        <location filename="window.py" line="271"/>
+        <source>Spell check</source>
+        <translation>スペルチェック</translation>
     </message>
     <message>
-        <location filename="window.py" line="1204"/>
-        <source>HTML code</source>
-        <translation>HTMLコード</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
-        <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Markdown と reStructuredText のためのシンプルでパワフルなエディタ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>作者: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
-        <source>Website</source>
-        <translation>Webサイト</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
-        <source>Markdown syntax</source>
-        <translation>Markdown記法</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
-        <source>reStructuredText syntax</source>
-        <translation>reStructuredText 文法</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="258"/>
+        <location filename="window.py" line="279"/>
         <source>Default markup</source>
         <translation>デフォルトマークアップ</translation>
     </message>
     <message>
-        <location filename="window.py" line="564"/>
-        <source>Preferences</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="282"/>
+        <source>Formatting</source>
+        <translation>書式</translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
-        <source>Set encoding</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="323"/>
+        <source>Search</source>
+        <translation>検索</translation>
     </message>
     <message>
-        <location filename="window.py" line="917"/>
+        <location filename="window.py" line="325"/>
+        <source>Case sensitively</source>
+        <translation>大文字と小文字を区別</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1141"/>
+        <source>New document</source>
+        <translation>新規文書</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="685"/>
+        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <translation>ファイルの内容を解析できません。&lt;a href=&quot;%s&quot;&gt;必要なモジュール&lt;/a&gt; がインストールされているか確認してください。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="748"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>どこかにファイルを保存してください。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
+        <source>Select one or several files to open</source>
+        <translation>開きたいファイル（複数可）を選択してください</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
+        <source>Supported files</source>
+        <translation>サポートされているファイル</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
+        <source>All files (*)</source>
+        <translation>すべてのファイル (*)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="927"/>
         <source>Select file encoding from the list:</source>
-        <translation type="unfinished"></translation>
+        <translation>ファイルの文字エンコーディングを選んでください：</translation>
     </message>
     <message>
-        <location filename="window.py" line="78"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="952"/>
+        <source>Plain text (*.txt)</source>
+        <translation>プレーンテキスト (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="86"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="955"/>
+        <source>%s files</source>
+        <comment>Example of final string: Markdown files</comment>
+        <translation>%s ファイル</translation>
     </message>
     <message>
-        <location filename="window.py" line="88"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="1040"/>
+        <source>Save file</source>
+        <translation>ファイルを保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="112"/>
-        <source>Table mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="982"/>
+        <source>Cannot save to file because it is read-only!</source>
+        <translation>読み取り専用ファイルのため保存できません。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1030"/>
+        <source>Export document to ODT</source>
+        <translation>文書をODTにエクスポート</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1030"/>
+        <source>OpenDocument text files (*.odt)</source>
+        <translation>OpenDocumentテキストファイル (*.odt)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>HTML files (*.html *.htm)</source>
+        <translation>HTMLファイル (*.html *.htm)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1062"/>
+        <source>Export document to PDF</source>
+        <translation>文書をPDFにエクスポート</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1062"/>
+        <source>PDF files (*.pdf)</source>
+        <translation>PDFファイル (*.pdf)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1079"/>
+        <source>Print document</source>
+        <translation>文書を印刷</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>Export document</source>
+        <translation>文書をエクスポート</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1119"/>
+        <source>Failed to execute the command:</source>
+        <translation>コマンドの実行に失敗しました:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1200"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation>このファイルは他のアプリケーションによって削除されました。
+終了する前にファイルを保存して下さい。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1208"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation>この文書は他のアプリケーションによって変更されました。
+再読み込みを行いますか(全ての変更は失われます)?
+</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1213"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation>再読み込みを選択しない場合、データの消失を避けるために自動保存機能はこのセッションで無効になります。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1237"/>
+        <source>The document has been modified.
+Do you want to save your changes?</source>
+        <translation>文書は変更されています。
+変更内容を保存しますか？</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1261"/>
+        <source>HTML code</source>
+        <translation>HTMLコード</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s(PyMarkups %s 利用)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>Simple but powerful editor for Markdown and reStructuredText</source>
+        <translation>Markdown と reStructuredText のためのシンプルでパワフルなエディタ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>作者: Dmitry Shachnev, 2011</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>Website</source>
+        <translation>Webサイト</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>Markdown syntax</source>
+        <translation>Markdown 記法</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>reStructuredText syntax</source>
+        <translation>reStructuredText 文法</translation>
     </message>
 </context>
 </TS>
