@@ -3,535 +3,553 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>行为</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Automatically save documents</source>
-        <translation type="unfinished"></translation>
+        <translation>自动保存文件</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore window geometry</source>
-        <translation type="unfinished"></translation>
+        <translation>恢复窗口位置大小</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Restore live preview state</source>
-        <translation type="unfinished"></translation>
+        <translation>恢复实时预览状态</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Open external links in ReText window</source>
-        <translation type="unfinished"></translation>
+        <translation>在ReText窗口中打开外部链接</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Open unknown files in plain text mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="config.py" line="66"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Markdown 语法扩展 (逗号分隔)</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Editor</source>
-        <translation type="unfinished"></translation>
+        <translation>编辑</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Highlight current line</source>
-        <translation type="unfinished"></translation>
+        <translation>高亮显示当前行</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Show line numbers</source>
-        <translation type="unfinished"></translation>
+        <translation>显示行号</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tab key inserts spaces</source>
-        <translation type="unfinished"></translation>
+        <translation>使用 空格 替换 Tab</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Tabulation width</source>
-        <translation type="unfinished"></translation>
+        <translation>Tab键宽度</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Display right margin at column</source>
-        <translation type="unfinished"></translation>
+        <translation>显示右列页边距</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Interface</source>
-        <translation type="unfinished"></translation>
+        <translation>交互界面</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Icon theme name</source>
-        <translation type="unfinished"></translation>
+        <translation>图标主题名称</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
-        <source>Markdown extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Color scheme file</source>
-        <translation type="unfinished"></translation>
+        <translation>配色方案文件</translation>
     </message>
     <message>
-        <location filename="config.py" line="54"/>
+        <location filename="config.py" line="66"/>
         <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
+        <translation>样式表文件</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="102"/>
+        <source>Help</source>
+        <translation>帮助</translation>
     </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="21"/>
+        <location filename="config.py" line="33"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>(none)</translation>
     </message>
     <message>
-        <location filename="config.py" line="28"/>
+        <location filename="config.py" line="40"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>打开文件</translation>
     </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="32"/>
+        <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation>输入语言名称 (例如: en_US)</translation>
+        <translation>输入语言名称 (例如: zh_CN)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="37"/>
+        <location filename="dialogs.py" line="49"/>
         <source>Set as default</source>
-        <translation type="unfinished"></translation>
+        <translation>设为默认</translation>
+    </message>
+</context>
+<context>
+    <name>Proxy</name>
+    <message>
+        <location filename="fakevimeditor.py" line="64"/>
+        <source>No write since last change (add ! to override)</source>
+        <translation>已修改但尚未保存（可用 ! 强制执行）</translation>
+    </message>
+    <message>
+        <location filename="fakevimeditor.py" line="121"/>
+        <source>Information</source>
+        <translation>信息</translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="61"/>
+        <location filename="window.py" line="82"/>
         <source>File toolbar</source>
         <translation>文件工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="63"/>
+        <location filename="window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>编辑工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="65"/>
+        <location filename="window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>搜索工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="90"/>
         <source>New</source>
         <translation>新建</translation>
     </message>
     <message>
-        <location filename="window.py" line="72"/>
+        <location filename="window.py" line="93"/>
         <source>Open</source>
         <translation>打开</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="96"/>
+        <source>Set encoding</source>
+        <translation>设置编码方式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1217"/>
+        <source>Reload</source>
+        <translation>重载</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="84"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
-        <translation>另存文件</translation>
+        <translation>另存为</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="107"/>
+        <source>Next tab</source>
+        <translation>下一个标签</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Previous tab</source>
+        <translation>上一个标签</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>打印</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>打印预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>查看 HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
-        <source>Change default font</source>
-        <translation>改变默认字体</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>查找文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="101"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="110"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>实时预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="114"/>
+        <location filename="window.py" line="137"/>
+        <source>Table mode</source>
+        <translation>表格样式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="140"/>
+        <source>FakeVim mode</source>
+        <translation>FakeVim 模式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="145"/>
         <source>Fullscreen mode</source>
         <translation>全屏模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="122"/>
+        <location filename="window.py" line="592"/>
+        <source>Preferences</source>
+        <translation>个人偏好</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="window.py" line="158"/>
         <source>Undo</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="window.py" line="127"/>
+        <location filename="window.py" line="160"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="window.py" line="162"/>
         <source>Copy</source>
         <translation>复制</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="164"/>
         <source>Cut</source>
         <translation>剪切</translation>
     </message>
     <message>
-        <location filename="window.py" line="133"/>
+        <location filename="window.py" line="166"/>
         <source>Paste</source>
         <translation>粘贴</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="176"/>
         <source>Enable</source>
         <translation>激活</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="window.py" line="177"/>
         <source>Set locale</source>
         <translation>选择界面语言</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
-        <source>Plain text</source>
-        <translation>普通文本</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="178"/>
         <source>Use WebKit renderer</source>
-        <translation>使用WebKit渲染</translation>
+        <translation>使用 WebKit 渲染</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
-        <source>Generate webpages</source>
-        <translation>生成网页</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="149"/>
-        <source>Show</source>
-        <translation>显示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="150"/>
-        <source>Next</source>
-        <translation>下一项</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="152"/>
-        <source>Previous</source>
-        <translation>上一项</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="154"/>
-        <source>Get help online</source>
-        <translation>在线获取帮助（英文）</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="155"/>
-        <source>About %s</source>
-        <comment>Example of final string: About ReText</comment>
-        <translation>关于 %s</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="159"/>
-        <source>About Qt</source>
-        <translation>关于 Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="179"/>
-        <source>Bold</source>
-        <translation>加粗</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="181"/>
-        <source>Italic</source>
-        <translation>傾斜</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="183"/>
-        <source>Underline</source>
-        <translation>下划线</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Tags</source>
-        <translation>标签</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="195"/>
-        <source>Symbols</source>
-        <translation>符号</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="209"/>
-        <source>File</source>
-        <translation>文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="210"/>
-        <source>Edit</source>
-        <translation>编辑</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="211"/>
-        <source>Help</source>
-        <translation>帮助</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="214"/>
-        <source>Open recent</source>
-        <translation>打开最近使用</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="217"/>
-        <source>Directory</source>
-        <translation>目录</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="229"/>
-        <source>Export</source>
-        <translation>导出</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="250"/>
-        <source>Spell check</source>
-        <translation>拼写检查</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="261"/>
-        <source>Formatting</source>
-        <translation>格式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="299"/>
-        <source>Search</source>
-        <translation>搜索</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="301"/>
-        <source>Case sensitively</source>
-        <translation>对大小写敏感</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1121"/>
-        <source>New document</source>
-        <translation>新文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="641"/>
-        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="739"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>请，保存到别的地方呦！</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="724"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
-        <translation>未能加载默认模板，请您手动创建 template.html</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="728"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>网页保存在 &lt;code&gt;html&lt;/code&gt; 文件夹。</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="730"/>
+        <location filename="window.py" line="180"/>
         <source>Show directory</source>
         <translation>显示文件夹</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
-        <source>Select one or several files to open</source>
-        <translation>选择一个或多个文件以打开</translation>
+        <location filename="window.py" line="181"/>
+        <source>Next</source>
+        <translation>下一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
+        <location filename="window.py" line="183"/>
+        <source>Previous</source>
+        <translation>上一项</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="185"/>
+        <source>Get help online</source>
+        <translation>在线获取帮助（英文）</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="189"/>
+        <source>About Qt</source>
+        <translation>关于 Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="209"/>
+        <source>Bold</source>
+        <translation>加粗</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="211"/>
+        <source>Italic</source>
+        <translation>倾斜</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="213"/>
+        <source>Underline</source>
+        <translation>下划线</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="221"/>
+        <source>Tags</source>
+        <translation>标签</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="225"/>
+        <source>Symbols</source>
+        <translation>符号</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="232"/>
+        <source>File</source>
+        <translation>文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="233"/>
+        <source>Edit</source>
+        <translation>编辑</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="234"/>
+        <source>Help</source>
+        <translation>帮助</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Open recent</source>
+        <translation>打开最近使用</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="250"/>
+        <source>Export</source>
+        <translation>导出</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="271"/>
+        <source>Spell check</source>
+        <translation>拼写检查</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="279"/>
+        <source>Default markup</source>
+        <translation>默认编辑模式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="282"/>
+        <source>Formatting</source>
+        <translation>字符样式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="323"/>
+        <source>Search</source>
+        <translation>搜索</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="325"/>
+        <source>Case sensitively</source>
+        <translation>对大小写敏感</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1141"/>
+        <source>New document</source>
+        <translation>新文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="685"/>
+        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <translation>不能处理文件内容，检查你是否安装了 &lt;a href=&quot;%s&quot;&gt;必需的模块&lt;/a&gt;！</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="748"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>请，保存到别的地方呦！</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
+        <source>Select one or several files to open</source>
+        <translation>选择一个或多个文件打开</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="868"/>
         <source>Supported files</source>
         <translation>支持的文件类型</translation>
     </message>
     <message>
-        <location filename="window.py" line="858"/>
+        <location filename="window.py" line="868"/>
         <source>All files (*)</source>
         <translation>全部文件 (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="942"/>
+        <location filename="window.py" line="927"/>
+        <source>Select file encoding from the list:</source>
+        <translation>从列表中选择文件编码方式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="952"/>
         <source>Plain text (*.txt)</source>
         <translation>普通文本文档 (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="945"/>
+        <location filename="window.py" line="955"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s 文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
+        <location filename="window.py" line="1040"/>
         <source>Save file</source>
         <translation>保存文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="965"/>
+        <location filename="window.py" line="982"/>
         <source>Cannot save to file because it is read-only!</source>
-        <translation>不能保存文件因为它是只读的！</translation>
+        <translation>不能保存文件因为当前文件或文件夹只读！</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
+        <location filename="window.py" line="1030"/>
         <source>Export document to ODT</source>
         <translation>导出文件到 ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1010"/>
+        <location filename="window.py" line="1030"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument 文本文件 (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1020"/>
+        <location filename="window.py" line="1040"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 文件 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
+        <location filename="window.py" line="1062"/>
         <source>Export document to PDF</source>
         <translation>导出文件到 PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1042"/>
+        <location filename="window.py" line="1062"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 文件 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="1079"/>
         <source>Print document</source>
         <translation>打印文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="window.py" line="1100"/>
         <source>Export document</source>
         <translation>导出文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="1099"/>
+        <location filename="window.py" line="1119"/>
         <source>Failed to execute the command:</source>
         <translation>不能执行命令:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1180"/>
+        <location filename="window.py" line="1200"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation>此文件已被其他应用程序删除。
+请确保在退出程序前保存了文件。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1208"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation>文件已被其他程序修改。
+要重新载入文件（丢弃所有修改）吗？
+</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1213"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation>如果不重新载入文件，将禁用该会话的自动保存模式，以防止数据丢失。</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1237"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>文件已更改，确认保存吗？</translation>
     </message>
     <message>
-        <location filename="window.py" line="1204"/>
+        <location filename="window.py" line="1261"/>
         <source>HTML code</source>
         <translation>HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>简单高效的 Markdown 与 ReStructuredText 编辑器</translation>
+        <translation>简单高效的 Markdown 与 reStructuredText 编辑器</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Website</source>
         <translation>网站</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>Markdown syntax</source>
         <translation>Markdown 语法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1272"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText 语法</translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
-        <source>Set encoding</source>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="564"/>
-        <source>Preferences</source>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="258"/>
-        <source>Default markup</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="186"/>
+        <source>About ReText</source>
+        <translation type="unfinished">关于 ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="917"/>
-        <source>Select file encoding from the list:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="78"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="86"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="88"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="112"/>
-        <source>Table mode</source>
+        <location filename="window.py" line="1272"/>
+        <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
