@@ -3,100 +3,100 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Behavior</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Automatically save documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Restore window geometry</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Restore live preview state</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Open external links in ReText window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
-        <source>Open unknown files in plain text mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Highlight current line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Show line numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Tab key inserts spaces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Display right margin at column</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Icon theme name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
-        <source>Markdown extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Color scheme file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="53"/>
+        <location filename="config.py" line="66"/>
         <source>Stylesheet file</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="config.py" line="66"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="102"/>
+        <source>Help</source>
+        <translation type="unfinished">說明</translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="21"/>
+        <location filename="config.py" line="33"/>
         <source>(none)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="28"/>
+        <location filename="config.py" line="40"/>
         <source>Select file to open</source>
         <translation type="unfinished"></translation>
     </message>
@@ -104,435 +104,450 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="32"/>
+        <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="37"/>
+        <location filename="dialogs.py" line="49"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Proxy</name>
+    <message>
+        <location filename="fakevimeditor.py" line="64"/>
+        <source>No write since last change (add ! to override)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="fakevimeditor.py" line="121"/>
+        <source>Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="72"/>
+        <location filename="window.py" line="93"/>
         <source>Open</source>
         <translation>開啟</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>儲存</translation>
     </message>
     <message>
-        <location filename="window.py" line="90"/>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>列印</translation>
     </message>
     <message>
-        <location filename="window.py" line="101"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>預覽</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="window.py" line="221"/>
         <source>Tags</source>
         <translation>書籤</translation>
     </message>
     <message>
-        <location filename="window.py" line="195"/>
+        <location filename="window.py" line="225"/>
         <source>Symbols</source>
         <translation>特殊符號</translation>
     </message>
     <message>
-        <location filename="window.py" line="1027"/>
+        <location filename="window.py" line="1040"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 檔案 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1027"/>
+        <location filename="window.py" line="1040"/>
         <source>Save file</source>
         <translation>儲存檔案</translation>
     </message>
     <message>
-        <location filename="window.py" line="84"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>另存新檔</translation>
     </message>
     <message>
-        <location filename="window.py" line="122"/>
+        <location filename="window.py" line="155"/>
         <source>Quit</source>
         <translation>離開</translation>
     </message>
     <message>
-        <location filename="window.py" line="159"/>
+        <location filename="window.py" line="189"/>
         <source>About Qt</source>
         <translation>關於 Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="209"/>
+        <location filename="window.py" line="232"/>
         <source>File</source>
         <translation>檔案</translation>
     </message>
     <message>
-        <location filename="window.py" line="210"/>
+        <location filename="window.py" line="233"/>
         <source>Edit</source>
         <translation>編輯</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="window.py" line="234"/>
         <source>Help</source>
         <translation>說明</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="window.py" line="250"/>
         <source>Export</source>
         <translation>匯出</translation>
     </message>
     <message>
-        <location filename="window.py" line="61"/>
+        <location filename="window.py" line="82"/>
         <source>File toolbar</source>
         <translation>檔案工具列</translation>
     </message>
     <message>
-        <location filename="window.py" line="63"/>
+        <location filename="window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>編輯工具列</translation>
     </message>
     <message>
-        <location filename="window.py" line="1049"/>
+        <location filename="window.py" line="1062"/>
         <source>Export document to PDF</source>
         <translation>匯出檔案到 PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1049"/>
+        <location filename="window.py" line="1062"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 檔案 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1187"/>
+        <location filename="window.py" line="1237"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>檔案已變更，確定儲存嗎？</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="window.py" line="158"/>
         <source>Undo</source>
         <translation>復原</translation>
     </message>
     <message>
-        <location filename="window.py" line="127"/>
+        <location filename="window.py" line="160"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="window.py" line="162"/>
         <source>Copy</source>
         <translation>複製</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="164"/>
         <source>Cut</source>
         <translation>剪下</translation>
     </message>
     <message>
-        <location filename="window.py" line="133"/>
+        <location filename="window.py" line="166"/>
         <source>Paste</source>
         <translation>貼上</translation>
     </message>
     <message>
-        <location filename="window.py" line="1128"/>
+        <location filename="window.py" line="1141"/>
         <source>New document</source>
         <translation>新檔</translation>
     </message>
     <message>
-        <location filename="window.py" line="865"/>
+        <location filename="window.py" line="868"/>
         <source>All files (*)</source>
         <translation>所有檔案 (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="90"/>
         <source>New</source>
         <translation>新增</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="window.py" line="237"/>
         <source>Open recent</source>
         <translation>開啟最近的</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
-        <source>Plain text</source>
-        <translation>純文本</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1017"/>
+        <location filename="window.py" line="1030"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Libreoffice 檔案 (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1017"/>
+        <location filename="window.py" line="1030"/>
         <source>Export document to ODT</source>
         <translation>匯出檔案到 ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>檢視 HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="window.py" line="1211"/>
+        <location filename="window.py" line="1261"/>
         <source>HTML code</source>
         <translation>HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>列印預覽</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1079"/>
         <source>Print document</source>
         <translation>列印檔案</translation>
     </message>
     <message>
-        <location filename="window.py" line="110"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>同步預覽</translation>
     </message>
     <message>
-        <location filename="window.py" line="735"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>網頁儲存在 &lt;code&gt;html&lt;/code&gt; 目錄。</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="746"/>
+        <location filename="window.py" line="748"/>
         <source>Please, save the file somewhere.</source>
         <translation>請，儲存到別的地方呦！</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
-        <source>Generate webpages</source>
-        <translation>產生網頁</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="949"/>
+        <location filename="window.py" line="952"/>
         <source>Plain text (*.txt)</source>
         <translation>純文本 (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
-        <source>Show</source>
-        <translation>顯示</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="217"/>
-        <source>Directory</source>
-        <translation>目錄</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="865"/>
+        <location filename="window.py" line="868"/>
         <source>Supported files</source>
         <translation>支持的檔案格式</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
-        <source>Change default font</source>
-        <translation>變更預設字型</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="window.py" line="1100"/>
         <source>Export document</source>
         <translation>匯出檔案</translation>
     </message>
     <message>
-        <location filename="window.py" line="143"/>
+        <location filename="window.py" line="176"/>
         <source>Enable</source>
         <translation>啟用</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="window.py" line="177"/>
         <source>Set locale</source>
         <translation>選擇程式語言</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="window.py" line="271"/>
         <source>Spell check</source>
         <translation>拼寫檢查</translation>
     </message>
     <message>
-        <location filename="window.py" line="114"/>
+        <location filename="window.py" line="145"/>
         <source>Fullscreen mode</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="window.py" line="65"/>
+        <location filename="window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>尋找工具列</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>尋找文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="150"/>
+        <location filename="window.py" line="181"/>
         <source>Next</source>
         <translation>下一條</translation>
     </message>
     <message>
-        <location filename="window.py" line="152"/>
+        <location filename="window.py" line="183"/>
         <source>Previous</source>
         <translation>上一條</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
+        <location filename="window.py" line="323"/>
         <source>Search</source>
         <translation>尋找</translation>
     </message>
     <message>
-        <location filename="window.py" line="301"/>
+        <location filename="window.py" line="325"/>
         <source>Case sensitively</source>
         <translation>對大小写敏感</translation>
     </message>
     <message>
-        <location filename="window.py" line="1222"/>
+        <location filename="window.py" line="1272"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1222"/>
+        <location filename="window.py" line="1272"/>
         <source>Website</source>
         <translation>部落格</translation>
     </message>
     <message>
-        <location filename="window.py" line="1222"/>
+        <location filename="window.py" line="1272"/>
         <source>Markdown syntax</source>
         <translation>Markdown 句法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1222"/>
+        <location filename="window.py" line="1272"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText 句法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1222"/>
+        <location filename="window.py" line="1272"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>簡單高效的 Markdown 與 reStructuredText 編輯器</translation>
     </message>
     <message>
-        <location filename="window.py" line="865"/>
+        <location filename="window.py" line="868"/>
         <source>Select one or several files to open</source>
         <translation>選擇一個或多個檔案以開啟</translation>
     </message>
     <message>
-        <location filename="window.py" line="154"/>
+        <location filename="window.py" line="185"/>
         <source>Get help online</source>
         <translation>在線擷取幫助（英文）</translation>
     </message>
     <message>
-        <location filename="window.py" line="737"/>
+        <location filename="window.py" line="180"/>
         <source>Show directory</source>
         <translation>顯示目錄</translation>
     </message>
     <message>
-        <location filename="window.py" line="972"/>
+        <location filename="window.py" line="982"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>不能儲存檔案因为它是只讀的！</translation>
     </message>
     <message>
-        <location filename="window.py" line="179"/>
+        <location filename="window.py" line="209"/>
         <source>Bold</source>
         <translation>加粗</translation>
     </message>
     <message>
-        <location filename="window.py" line="181"/>
+        <location filename="window.py" line="211"/>
         <source>Italic</source>
         <translation>傾斜</translation>
     </message>
     <message>
-        <location filename="window.py" line="183"/>
+        <location filename="window.py" line="213"/>
         <source>Underline</source>
         <translation>下劃線</translation>
     </message>
     <message>
-        <location filename="window.py" line="261"/>
+        <location filename="window.py" line="282"/>
         <source>Formatting</source>
         <translation>樣式</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
-        <source>About %s</source>
-        <comment>Example of final string: About ReText</comment>
-        <translation>關於 %s</translation>
+        <location filename="window.py" line="186"/>
+        <source>About ReText</source>
+        <translation>關於 ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="178"/>
         <source>Use WebKit renderer</source>
         <translation>使用WebKit渲染</translation>
     </message>
     <message>
-        <location filename="window.py" line="1106"/>
+        <location filename="window.py" line="1119"/>
         <source>Failed to execute the command:</source>
         <translation>不能執行指令:</translation>
     </message>
     <message>
-        <location filename="window.py" line="952"/>
+        <location filename="window.py" line="955"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s 檔案</translation>
     </message>
     <message>
-        <location filename="window.py" line="731"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="648"/>
+        <location filename="window.py" line="685"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="258"/>
+        <location filename="window.py" line="279"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="574"/>
+        <location filename="window.py" line="592"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="75"/>
+        <location filename="window.py" line="96"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="924"/>
+        <location filename="window.py" line="927"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="78"/>
+        <location filename="window.py" line="1217"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="86"/>
+        <location filename="window.py" line="107"/>
         <source>Next tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="88"/>
+        <location filename="window.py" line="109"/>
         <source>Previous tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="112"/>
+        <location filename="window.py" line="137"/>
         <source>Table mode</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="140"/>
+        <source>FakeVim mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1200"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1208"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1213"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1272"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
